@@ -1,7 +1,7 @@
 import contextlib
-import warnings
 
 import dask.dataframe as dd
+
 from dagster import (
     Any,
     AssetMaterialization,
@@ -10,27 +10,36 @@ from dagster import (
     DagsterType,
     Enum,
     EnumValue,
-    EventMetadataEntry,
     Field,
     Int,
+    MetadataEntry,
     Permissive,
     Selector,
     Shape,
     String,
     TypeCheck,
-    check,
-    dagster_type_loader,
-    dagster_type_materializer,
 )
+from dagster import _check as check
+from dagster import dagster_type_loader, dagster_type_materializer
 
 from .utils import DataFrameUtilities, apply_utilities_to_df
 
 WriteCompressionTextOptions = Enum(
-    "WriteCompressionText", [EnumValue("gzip"), EnumValue("bz2"), EnumValue("xz"),],
+    "WriteCompressionText",
+    [
+        EnumValue("gzip"),
+        EnumValue("bz2"),
+        EnumValue("xz"),
+    ],
 )
 
 EngineParquetOptions = Enum(
-    "EngineParquet", [EnumValue("auto"), EnumValue("fastparquet"), EnumValue("pyarrow"),],
+    "EngineParquet",
+    [
+        EnumValue("auto"),
+        EnumValue("fastparquet"),
+        EnumValue("pyarrow"),
+    ],
 )
 
 
@@ -40,7 +49,11 @@ DataFrameReadTypes = {
         "is_path_based": True,
         "options": {
             "path": (Any, True, "Absolute or relative filepath(s)."),
-            "blocksize": (Any, False, "Number of bytes by which to cut up larger files."),
+            "blocksize": (
+                Any,
+                False,
+                "Number of bytes by which to cut up larger files.",
+            ),
             "sample": (Int, False, "Number of bytes to use when determining dtypes."),
             "assume_missing": (
                 Bool,
@@ -64,7 +77,11 @@ DataFrameReadTypes = {
         "is_path_based": True,
         "options": {
             "path": (Any, True, "Absolute or relative filepath(s)."),
-            "columns": (Any, False, "Field name(s) to read in as columns in the output."),
+            "columns": (
+                Any,
+                False,
+                "Field name(s) to read in as columns in the output.",
+            ),
             "filters": (Any, False, "List of filters to apply."),
             "index": (Any, False, "Field name(s) to use as the output frame index."),
             "categories": (
@@ -78,7 +95,11 @@ DataFrameReadTypes = {
                 "Key/value pairs to be passed on to the file-system backend, if any.",
             ),
             "engine": (EngineParquetOptions, False, "Parquet reader library to use."),
-            "gather_statistics": (Bool, False, "Gather the statistics for each dataset partition."),
+            "gather_statistics": (
+                Bool,
+                False,
+                "Gather the statistics for each dataset partition.",
+            ),
             "split_row_groups": (
                 Bool,
                 False,
@@ -102,7 +123,11 @@ DataFrameReadTypes = {
                 False,
                 "Option to specify whether or not the input hdf files have a sorted index.",
             ),
-            "lock": (Bool, False, "Option to use a lock to prevent concurrency issues."),
+            "lock": (
+                Bool,
+                False,
+                "Option to use a lock to prevent concurrency issues.",
+            ),
             "mode": (String, False, "Mode to use when opening file(s)."),
         },
     },
@@ -118,7 +143,11 @@ DataFrameReadTypes = {
                 False,
                 "Passed to backend file-system implementation.",
             ),
-            "blocksize": (Int, False, "Each partition will be approximately this size in bytes."),
+            "blocksize": (
+                Int,
+                False,
+                "Each partition will be approximately this size in bytes.",
+            ),
             "sample": (
                 Int,
                 False,
@@ -138,10 +167,22 @@ DataFrameReadTypes = {
                 True,
                 "Column which becomes the index, and defines the partitioning.",
             ),
-            "divisions": (Any, False, "Values of the index column to split the table by."),
-            "npartitions": (Int, False, "Number of partitions, if divisions is not given."),
+            "divisions": (
+                Any,
+                False,
+                "Values of the index column to split the table by.",
+            ),
+            "npartitions": (
+                Int,
+                False,
+                "Number of partitions, if divisions is not given.",
+            ),
             "columns": (Any, False, "Which columns to select."),
-            "bytes_per_chunk": (Any, False, "The target size of each partition, in bytes."),
+            "bytes_per_chunk": (
+                Any,
+                False,
+                "The target size of each partition, in bytes.",
+            ),
             "head_rows": (
                 Int,
                 False,
@@ -159,7 +200,11 @@ DataFrameReadTypes = {
         "is_path_based": True,
         "options": {
             "path": (Any, True, "Absolute or relative filepath(s)."),
-            "blocksize": (Any, False, "Number of bytes by which to cut up larger files."),
+            "blocksize": (
+                Any,
+                False,
+                "Number of bytes by which to cut up larger files.",
+            ),
             "sample": (Int, False, "Number of bytes to use when determining dtypes."),
             "assume_missing": (
                 Bool,
@@ -183,7 +228,11 @@ DataFrameReadTypes = {
         "is_path_based": True,
         "options": {
             "path": (Any, True, "Absolute or relative filepath(s)."),
-            "blocksize": (Any, False, "Number of bytes by which to cut up larger files."),
+            "blocksize": (
+                Any,
+                False,
+                "Number of bytes by which to cut up larger files.",
+            ),
             "sample": (Int, False, "Number of bytes to use when determining dtypes."),
             "assume_missing": (
                 Bool,
@@ -223,8 +272,16 @@ DataFrameToTypes = {
         "function": dd.DataFrame.to_csv,
         "is_path_based": True,
         "options": {
-            "path": (Any, True, "Path glob indicating the naming scheme for the output files"),
-            "single_file": (Bool, False, "Whether to save everything into a single CSV file."),
+            "path": (
+                Any,
+                True,
+                "Path glob indicating the naming scheme for the output files",
+            ),
+            "single_file": (
+                Bool,
+                False,
+                "Whether to save everything into a single CSV file.",
+            ),
             "encoding": (
                 String,
                 False,
@@ -255,7 +312,11 @@ DataFrameToTypes = {
                 'Either a string like ``"snappy"`` or a dictionary mapping column names to compressors like ``{"name": "gzip", "values": "snappy"}``.',
             ),
             "write_index": (Bool, False, "Whether or not to write the index."),
-            "append": (Bool, False, "Whether to add new row-group(s) to an existing data-set."),
+            "append": (
+                Bool,
+                False,
+                "Whether to add new row-group(s) to an existing data-set.",
+            ),
             "ignore_divisions": (
                 Bool,
                 False,
@@ -281,6 +342,11 @@ DataFrameToTypes = {
                 False,
                 "Options to be passed in to the compute method.",
             ),
+            "schema": (
+                Any,
+                False,
+                "Global schema to use for the output dataset.",
+            ),
         },
     },
     "hdf": {
@@ -289,7 +355,11 @@ DataFrameToTypes = {
         "options": {
             "path": (Any, True, "Path to a target filename."),
             "key": (String, True, "Datapath within the files."),
-            "scheduler": (String, False, 'The scheduler to use, like "threads" or "processes".'),
+            "scheduler": (
+                String,
+                False,
+                'The scheduler to use, like "threads" or "processes".',
+            ),
         },
     },
     "json": {
@@ -318,7 +388,11 @@ DataFrameToTypes = {
         "options": {
             "name": (String, True, "Name of SQL table."),
             "uri": (String, True, "Full sqlalchemy URI for the database connection."),
-            "schema": (String, False, "Specify the schema (if database flavor supports this)."),
+            "schema": (
+                String,
+                False,
+                "Specify the schema (if database flavor supports this).",
+            ),
             "if_exists": (String, False, "How to behave if the table already exists."),
             "index": (Bool, False, "Write DataFrame index as a column."),
             "index_label": (Any, False, "Column label for index column(s)."),
@@ -344,7 +418,9 @@ def _dataframe_loader_config():
         read_from: Permissive(
             {
                 option_name: Field(
-                    option_args[0], is_required=option_args[1], description=option_args[2]
+                    option_args[0],
+                    is_required=option_args[1],
+                    description=option_args[2],
                 )
                 for option_name, option_args in read_opts["options"].items()
             }
@@ -354,34 +430,20 @@ def _dataframe_loader_config():
 
     return Shape(
         {
-            "read": Field(Selector(read_fields), is_required=False,),
+            "read": Field(
+                Selector(read_fields),
+            ),
             **{
                 util_name: util_spec["options"]
                 for util_name, util_spec in DataFrameUtilities.items()
             },
-            # https://github.com/dagster-io/dagster/issues/2872
-            **{
-                field_name: Field(field_config, is_required=False,)
-                for field_name, field_config in read_fields.items()
-            },
         }
     )
 
 
 @dagster_type_loader(_dataframe_loader_config())
 def dataframe_loader(_context, config):
-    read_type, read_options = None, None
-    if "read" in config:
-        read_type, read_options = next(iter(config["read"].items()))
-
-    # https://github.com/dagster-io/dagster/issues/2872
-    else:
-        for key in DataFrameReadTypes:
-            if key in config:
-                read_type, read_options = key, config[key]
-                warnings.warn(
-                    "Specifying {key}: is deprecated. Use read:{key}: instead.".format(key=key)
-                )
+    read_type, read_options = next(iter(config["read"].items()))
 
     if not read_type:
         raise DagsterInvariantViolationError("No read_type found. Expected read key in config.")
@@ -414,7 +476,9 @@ def _dataframe_materializer_config():
         write_to: Permissive(
             {
                 option_name: Field(
-                    option_args[0], is_required=option_args[1], description=option_args[2]
+                    option_args[0],
+                    is_required=option_args[1],
+                    description=option_args[2],
                 )
                 for option_name, option_args in to_opts["options"].items()
             }
@@ -424,16 +488,13 @@ def _dataframe_materializer_config():
 
     return Shape(
         {
-            "to": Field(Selector(to_fields), is_required=False,),
+            "to": Field(
+                Selector(to_fields),
+            ),
             **{
                 util_name: util_spec["options"]
                 for util_name, util_spec in DataFrameUtilities.items()
             },
-            # https://github.com/dagster-io/dagster/issues/2872
-            **{
-                field_name: Field(field_config, is_required=False,)
-                for field_name, field_config in to_fields.items()
-            },
         }
     )
 
@@ -442,18 +503,7 @@ def _dataframe_materializer_config():
 def dataframe_materializer(_context, config, dask_df):
     check.inst_param(dask_df, "dask_df", dd.DataFrame)
 
-    if "to" in config:
-        to_specs = config["to"]
-
-    # https://github.com/dagster-io/dagster/issues/2872
-    else:
-        to_specs = {
-            to_type: to_options
-            for to_type, to_options in config.items()
-            if to_type in DataFrameToTypes
-        }
-        for key in to_specs.keys():
-            warnings.warn("Specifying {key}: is deprecated. Use to:{key}: instead.".format(key=key))
+    to_specs = config["to"]
 
     # Apply any utility functions in preparation for materialization
     dask_df = apply_utilities_to_df(dask_df, config)
@@ -496,7 +546,7 @@ def df_type_check(_, value):
         success=True,
         metadata_entries=[
             # string cast columns since they may be things like datetime
-            EventMetadataEntry.json({"columns": list(map(str, value.columns))}, "metadata"),
+            MetadataEntry("metadata", value={"columns": list(map(str, value.columns))}),
         ],
     )
 
