@@ -1,15 +1,18 @@
 import dask
 import dask.distributed
-from dagster import Executor, Field, Permissive, Selector, StringSource, check, seven
-from dagster.core.definitions.executor import check_cross_process_constraints, executor
-from dagster.core.errors import raise_execution_interrupts
-from dagster.core.events import DagsterEvent
-from dagster.core.execution.api import create_execution_plan, execute_plan
-from dagster.core.execution.context.system import SystemPipelineExecutionContext
-from dagster.core.execution.plan.plan import ExecutionPlan
-from dagster.core.execution.retries import RetryMode
-from dagster.core.instance import DagsterInstance
-from dagster.utils import frozentags, iterate_with_context
+
+from dagster import Executor, Field, Permissive, Selector, StringSource
+from dagster import _check as check
+from dagster import _seven, multiple_process_executor_requirements
+from dagster._core.definitions.executor_definition import executor
+from dagster._core.errors import raise_execution_interrupts
+from dagster._core.events import DagsterEvent
+from dagster._core.execution.api import create_execution_plan, execute_plan
+from dagster._core.execution.context.system import PlanOrchestrationContext
+from dagster._core.execution.plan.plan import ExecutionPlan
+from dagster._core.execution.retries import RetryMode
+from dagster._core.instance import DagsterInstance
+from dagster._utils import frozentags, iterate_with_context
 
 # Dask resource requirements are specified under this key
 DASK_RESOURCE_REQUIREMENTS_KEY = "dagster-dask/resource_requirements"
@@ -17,6 +20,7 @@ DASK_RESOURCE_REQUIREMENTS_KEY = "dagster-dask/resource_requirements"
 
 @executor(
     name="dask",
+    requirements=multiple_process_executor_requirements(),
     config_schema={
         "cluster": Field(
             Selector(
@@ -86,21 +90,18 @@ def dask_executor(init_context):
                     }
             }
 
-    If you'd like to configure a dask executor in addition to the
-    :py:class:`~dagster.default_executors`, you should add it to the ``executor_defs`` defined on a
-    :py:class:`~dagster.ModeDefinition` as follows:
+    To use the `dask_executor`, set it as the `executor_def` when defining a job:
 
     .. code-block:: python
 
-        from dagster import ModeDefinition, default_executors, pipeline
+        from dagster import job
         from dagster_dask import dask_executor
 
-        @pipeline(mode_defs=[ModeDefinition(executor_defs=default_executors + [dask_executor])])
-        def dask_enabled_pipeline():
+        @job(executor_def=dask_executor)
+        def dask_enabled_job():
             pass
 
     """
-    check_cross_process_constraints(init_context)
     ((cluster_type, cluster_configuration),) = init_context.executor_config["cluster"].items()
     return DaskExecutor(cluster_type, cluster_configuration)
 
@@ -113,29 +114,35 @@ def query_on_dask_worker(
     step_keys,
     mode,
     instance_ref,
+    known_state,
 ):  # pylint: disable=unused-argument
     """Note that we need to pass "dependencies" to ensure Dask sequences futures during task
     scheduling, even though we do not use this argument within the function.
     """
 
     with DagsterInstance.from_ref(instance_ref) as instance:
+        subset_pipeline = recon_pipeline.subset_for_execution_from_existing_pipeline(
+            pipeline_run.solids_to_execute
+        )
+
         execution_plan = create_execution_plan(
-            recon_pipeline.subset_for_execution_from_existing_pipeline(
-                pipeline_run.solids_to_execute
-            ),
+            subset_pipeline,
             run_config=run_config,
             step_keys_to_execute=step_keys,
             mode=mode,
+            known_state=known_state,
         )
 
-        return execute_plan(execution_plan, instance, pipeline_run, run_config=run_config)
+        return execute_plan(
+            execution_plan, subset_pipeline, instance, pipeline_run, run_config=run_config
+        )
 
 
 def get_dask_resource_requirements(tags):
     check.inst_param(tags, "tags", frozentags)
     req_str = tags.get(DASK_RESOURCE_REQUIREMENTS_KEY)
     if req_str is not None:
-        return seven.json.loads(req_str)
+        return _seven.json.loads(req_str)
 
     return {}
 
@@ -151,25 +158,25 @@ class DaskExecutor(Executor):
     def retries(self):
         return RetryMode.DISABLED
 
-    def execute(self, pipeline_context, execution_plan):
-        check.inst_param(pipeline_context, "pipeline_context", SystemPipelineExecutionContext)
+    def execute(self, plan_context, execution_plan):
+        check.inst_param(plan_context, "plan_context", PlanOrchestrationContext)
         check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
         check.param_invariant(
-            isinstance(pipeline_context.executor, DaskExecutor),
-            "pipeline_context",
-            "Expected executor to be DaskExecutor got {}".format(pipeline_context.executor),
+            isinstance(plan_context.executor, DaskExecutor),
+            "plan_context",
+            "Expected executor to be DaskExecutor got {}".format(plan_context.executor),
         )
 
         check.invariant(
-            pipeline_context.instance.is_persistent,
+            plan_context.instance.is_persistent,
             "Dask execution requires a persistent DagsterInstance",
         )
 
         step_levels = execution_plan.get_steps_to_execute_by_level()
 
-        pipeline_name = pipeline_context.pipeline_name
+        pipeline_name = plan_context.pipeline_name
 
-        instance = pipeline_context.instance
+        instance = plan_context.instance
 
         cluster_type = self.cluster_type
         if cluster_type == "existing":
@@ -233,22 +240,25 @@ class DaskExecutor(Executor):
                         for key in step_input.dependency_keys:
                             dependencies.append(execution_futures_dict[key])
 
-                    run_config = dict(pipeline_context.run_config, execution={"in_process": {}})
-                    recon_repo = pipeline_context.pipeline.get_reconstructable_repository()
+                    if plan_context.pipeline.get_definition().is_job:
+                        run_config = plan_context.run_config
+                    else:
+                        run_config = dict(plan_context.run_config, execution={"in_process": {}})
 
                     dask_task_name = "%s.%s" % (pipeline_name, step.key)
 
-                    recon_pipeline = recon_repo.get_reconstructable_pipeline(pipeline_name)
+                    recon_pipeline = plan_context.reconstructable_pipeline
 
                     future = client.submit(
                         query_on_dask_worker,
                         dependencies,
                         recon_pipeline,
-                        pipeline_context.pipeline_run,
+                        plan_context.pipeline_run,
                         run_config,
                         [step.key],
-                        pipeline_context.mode_def.name,
+                        plan_context.pipeline_run.mode,
                         instance.get_ref(),
+                        execution_plan.known_state,
                         key=dask_task_name,
                         resources=get_dask_resource_requirements(step.tags),
                     )
